cd "YOUR PATH"
set more off
set mem 600m

***Part 1***
***Person register***

use udb_c10r_silc_course.dta, clear

***Generating uniform identifiers***

rename RX030 ID_HH
rename RB030 ID_Pers
rename RB010 ID010
rename RB020 ID020



***Counting the number of Children under 18 in the HH***
***Note: children defined as persons under 18 ***
***Note: egen(count) counts nonmissing values only*** 
***Two steps first generate an individuall identifier then count in HH***

gen child=.
recode child .=1 if RX010<18 
tab child

egen childc =count(child) , by(ID010 ID020 ID_HH)
label var childc "Number of children under 18 in HH"

***In order to be able to display frequencies for households we need a variable identifying the first person in the HH***

egen HHrank=rank(RX010), by(ID010 ID020 ID_HH)

tab childc if HHrank==1
tab RB020 childc if HHrank==1, row



***Age of youngest child***
***Define age of the youngest household member for all households with persons under 18 years of age***
***For those HH with children (childc>0) youngest age is counted***

egen ychild=min(RX010)if childc>0, by(ID010 ID020 ID_HH)   
label var ychild "age of the youngest child in the HH"

tab ychild if HHrank==1, m
table RB020 if HHrank==1, c (m ychild)


***Youngest child categorial***

gen ychildcat=ychild
recode ychildcat  (0/3=1) (3/5=2) (6/17=3) (.=0) 
label define ychildcat 0 "no child" 1 "under 3" 2 "3 to 5" 3 "6 to 17" 
label val ychildcat ychildcat

tab ychildcat if HHrank==1, m
tab RB020 ychildcat if HHrank==1, m row


***Households with single parents***
***Step 1 identify parents***
***First we have to rank children in the HH by age***
***For each child in the household (max 4) we need to generate a variable identifying mother and father on the HH level****
***Then a dummy variable (mom or dad) is generated for those HH members whose personnumber matches the parent id of any child***

egen childrank=rank(RX010)if child==1, by(ID010 ID020 ID_HH) unique

gen mom=.
gen dad=.
foreach i in 1 2 3 4 {
gen long mtemp`i'=RB230 if childrank==`i'
gen long dtemp`i'=RB220 if childrank==`i'
egen long momchild`i'=mean(mtemp`i'), by(ID010 ID020 ID_HH)
egen long dadchild`i'=mean(dtemp`i'), by(ID010 ID020 ID_HH)
recode mom .=1 if momchild`i'==ID_Pers
recode dad .=1 if dadchild`i'==ID_Pers
}

drop mtemp* dtemp* 

***Step 2 check relationship status of parents and generate dummies for singleparents and generate a HH level dummy***

gen singleparent=0
recode singleparent 0=1 if (mom==1 | dad==1) & RB240==.
label define single 0 "other" 1 "single parent"
label val singleparent single
tab singleparent RB090

egen singleparentHH=max(singleparent), by(ID010 ID020 ID_HH)
recode singleparentHH .=0
label define singleHH 0 "no single parent in HH" 1 "single parent in HH"
label val singleparentHH singleHH 

tab singleparentHH if HHrank==1

***Use of childcare***
***Total duration of childcare use for children under 6***
***Step one set missing to zero for the individual childcare items***

gen RL010e=RL010
gen RL030e=RL030
gen RL040e=RL040
gen RL050e=RL050

recode RL010e .=0
recode RL030e .=0
recode RL040e .=0
recode RL050e .=0

***Step 2: Generate an additive indicator***

gen durchildcare=RL010e + RL030e + RL040e + RL050e if RX010<6
tab durchildcare child, m
label var durchildcare "attendance of childcare facilities in hours for children under 6"

***Counting the number of children under 3 in the HH***

gen under3=.
recode under3 .=1 if RX010<3 

egen under3c =count(under3) , by(ID010 ID020 ID_HH)
label var under3c "Number of children under 3 in HH"
tab under3c if HHrank==1
tab RB020 under3c if HHrank==1, row

***Counting the number of children between 3 and 5 in the HH***

gen kindergarten=.
recode kindergarten .=1 if RX010>=3 & RX010<6 

egen kindergartenc =count(kindergarten) , by(ID010 ID020 ID_HH)
label var kindergartenc "Number of children between 3 and 5 in HH"
tab kindergartenc if HHrank==1
tab RB020 kindergartenc if HHrank==1, row


mean durchildcare if under3==1
mean durchildcare if kindergarten==1

table RB020 if under3==1, c(m durchildcare) 
table RB020 if kindergarten==1, c(m durchildcare) 

***Bonus Exercise***
***Percentage of children under 6 using childcare facilities***

gen usechildcare=durchildcare>0 if RX010<6 
label define usechildcare 0 "Does not use childcare" 1 "uses childcare for at least 1 hour a week"
label val usechildcare usechildcare

table RB020 under3, c(m usechildcare)
table RB020 kindergarten, c(m usechildcare)

***Save the modified person register dataset***

sort ID010 ID020 ID_Pers

save personregister.dta, replace

***Exercise 2***
***Personal data***

use udb_c10p_silc_course.dta, clear

***Generating a 3 category educational variable***

gen educ=PE040
recode educ 0 1 2=1 3 4 =2 5=3
label define educ 1 "low" 2 "medium" 3 "high"
label values educ educ
 
***Generating a variable working status***

gen ecoactive=0
recode ecoactive 0=1 if PL031==1 | PL031==2 | PL031==3 | PL031==4


gen workstatus=PL060
recode workstatus (0/30=2) (31/max=3)
replace workstatus=1 if ecoactive==0 
label define workstatus 1 "inactive" 2 "working 30 hours or less" 3 "working more than 30 hours"
label val workstatus workstatus

bysort PB150: tab PB020 workstatus, row

tab educ workstatus, row

***Harmonizing IDs***

rename PX030 ID_HH
rename PB030 ID_Pers
rename PB010 ID010
rename PB020 ID020


sort ID010 ID020 ID_Pers


***Transitions into and out of unemployment***

gen transunemp=0
recode transunemp 0=1 if PL211A!=5 &PL211B==5
recode transunemp 0=1 if PL211B!=5 &PL211C==5
recode transunemp 0=1 if PL211C!=5 &PL211D==5
recode transunemp 0=1 if PL211D!=5 &PL211E==5
recode transunemp 0=1 if PL211E!=5 &PL211F==5
recode transunemp 0=1 if PL211F!=5 &PL211G==5
recode transunemp 0=1 if PL211G!=5 &PL211H==5
recode transunemp 0=1 if PL211H!=5 &PL211I==5
recode transunemp 0=1 if PL211I!=5 &PL211J==5
recode transunemp 0=1 if PL211J!=5 &PL211K==5
recode transunemp 0=1 if PL211K!=5 &PL211L==5

tab RB020 transunemp
tab educ transunemp, row

save persondata.dta, replace

***Exercise 3***
***Personal data and Personal register***

***Merging of Persondata and Person register*** 

sort ID010 ID020 ID_Pers
merge 1:1 ID010 ID020 ID_Pers using personregister.dta
tab _merge
keep if _merge==3
drop _merge
save person.dta, replace

***Examining mother's economic activity***

tab workstatus if mom==1

tab workstatus if mom==1 & singleparent==1

***M-logit regression***
*** i. converts categorial variables into multiple dummies***

mlogit workstatus i.ychildcat  singleparent i.RB020_num i.educ RX010 if RX010>=18 & RX010<65 & RB090==2 & PE010==2, base(3)


***Save the combined dataset***

save persondata&register.dta, replace

***Part 3***
***Combining Person and HH data***
***Merge person and household level data***

sort ID010 ID020 ID_HH
merge m:1 ID010 ID020 ID_HH using household_data.dta
tab _merge
keep if _merge==3
drop _merge

tab educ HS120, row

***Ability to make ends meet Dummy***

gen makeends=. 
recode makeends .=0 if HS120==1 | HS120==2 | HS120==3
recode makeends .=1 if HS120==4 | HS120==5 | HS120==6
label define makeends 0 "difficult" 1 "easily"
label val makeends makeends
tab makeends

***Highest Education in the Household***

egen heducHH=max(educ), by(ID010 ID020 ID_HH)  


***Number of persons working more than 30 hours in the HH***

gen work30=1 if workstatus==3

egen work30HH=sum(work30), by(ID010 ID020 ID_HH) 

***Household level regression***

logit makeends childc heducHH work30HH i.RB020_num if HHrank==1


***Individual level regression***

logit makeends i.educ i.workstatus i.RB020_num

***Save the integrated data set***

save person&HHdata.dta, replace

***Part 4: Exploring the data***
***Generating old OECD-scale***
***As we need all HH members go back to the person register file***
***Generating the weight***
use personregister.dta, replace

gen oecdoldweight=0
recode oecdoldweight 0=1 if HHrank==1 & RX010>=15
recode oecdoldweight 0=0.7 if HHrank!=1 & RX010>=15
recode oecdoldweight 0=0.5 if RX010<18

tab oecdoldweight

egen oecdoldHHweight=sum(oecdoldweight), by(ID010 ID020 ID_HH)  

table RB020 if HHrank==1, c (m oecdoldHHweight)

keep oecdoldHHweight ID010 ID020 ID_Pers

save oldOECDweight.dta, replace

***Merging***

sort ID010 ID020 ID_Pers
merge 1:1 ID010 ID020 ID_Pers using person&HHdata.dta
tab _merge
keep if _merge==3
drop _merge
save person&HHdata.dta, replace

***Calculating equivalized income***

gen oldoecd=(HY020+pens)/oecdoldHHweight

table HB020, c (m oldoecd m HX090)

table HX040, c (m oldoecd m HX090)

table HX060, c (m oldoecd m HX090)



***Transitions into employment***

gen transunempemp=0
recode transunempemp 0=1 if PL211A==5 & (PL211B==1 | PL211B==2 | PL211B==3 | PL211B==4)

gen transinaemp=0
recode transinaemp 0=1 if (PL211A==6 | PL211A==7 | PL211A==8 | PL211A==9 | PL211A==10 | PL211A==11 ) & (PL211B==1 | PL211B==2 | PL211B==3 | PL211B==4)

tab transunempemp

tab transinaemp


